@@ -15,34 +15,41 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.10',
  'BLDLIBRARY': '-L. -lpython3.10',
- 'BLDSHARED': 'gcc -pthread -shared '
-              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+ 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
  'BYTESTR_DEPS': '\\',
- 'CC': 'gcc -pthread',
+ 'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -march=armv7-a -mfloat-abi=hard '
-           '-mfpu=vfpv3-d16 -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-           '-fstack-protector-strong -fno-plt',
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+           '-fstack-protector-strong -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection -march=armv7-a -mfloat-abi=hard '
+           '-mfpu=neon -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection '
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+           '-fstack-protector-strong -fno-plt -fexceptions         '
+           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
+           '-fstack-clash-protection',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 '
-                     '-pipe -fstack-protector-strong -fno-plt',
+ 'CONFIGURE_CFLAGS': '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                     '-fstack-protector-strong -fno-plt -fexceptions         '
+                     '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                     '-Werror=format-security         -fstack-clash-protection',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
- 'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
+ 'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
@@ -51,19 +58,21 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--with-tzpath=/usr/share/zoneinfo' 'CFLAGS=-march=armv7-a "
-                '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                "-fstack-protector-strong -fno-plt' "
+                '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                '-fstack-protector-strong -fno-plt -fexceptions         '
+                '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                "-Werror=format-security         -fstack-clash-protection' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
-                "'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
+                "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.10.2/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.10.2/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.10.3/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.10.3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
- 'CXX': 'g++ -pthread',
+ 'CPPFLAGS': '-I. -I./Include',
+ 'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib /usr/lib/python3.10 '
              '/usr/lib/python3.10/lib-dynload',
  'DESTLIB': '/usr/lib/python3.10',
@@ -132,7 +141,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
- 'HAVE_CLOSE_RANGE': 0,
+ 'HAVE_CLOSE_RANGE': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -290,6 +299,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
  'HAVE_LINUX_CAN_J1939_H': 1,
@@ -545,14 +555,13 @@ build_time_vars = {'ABIFLAGS': '',
  'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'g++ -pthread -shared',
+ 'LDCXXSHARED': 'g++ -shared',
  'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared '
-             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+ 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDVERSION': '3.10',
  'LIBC': '',
@@ -569,9 +578,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBRARY_DEPS': 'libpython3.10.a libpython3.10.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
+ 'LIBS': '-lcrypt -ldl  -lm',
  'LIBSUBDIRS': 'asyncio \\',
- 'LINKCC': 'gcc -pthread',
+ 'LINKCC': 'gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
@@ -584,7 +593,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'gcc -pthread',
+ 'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
@@ -654,46 +663,64 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                             '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                             '-fstack-protector-strong -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wformat -Werror=format-security         '
+                             '-fstack-clash-protection -march=armv7-a '
+                             '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                             '-fstack-protector-strong -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wformat -Werror=format-security         '
+                             '-fstack-clash-protection -march=armv7-a '
+                             '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                             '-fstack-protector-strong -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wformat -Werror=format-security         '
+                             '-fstack-clash-protection -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -D_FORTIFY_SOURCE=2 '
-                             '-D_FORTIFY_SOURCE=2 -fPIC '
-                             '-DPy_BUILD_CORE_BUILTIN',
+                             '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=armv7-a '
-              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=armv7-a '
-              '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-              '-fstack-protector-strong -fno-plt',
+              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+              '-fstack-protector-strong -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+              '-fstack-protector-strong -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection '
+              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+              '-fstack-protector-strong -fno-plt -fexceptions         '
+              '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+              '-Werror=format-security         -fstack-clash-protection',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -march=armv7-a -mfloat-abi=hard -mfpu=vfpv3-d16 -O3 '
-                   '-pipe -fstack-protector-strong -fno-plt -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=vfpv3-d16 -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wall -march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
-                   '-D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
+                   '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'PY_CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
+ 'PY_CPPFLAGS': '-I. -I./Include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
@@ -702,18 +729,26 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -march=armv7-a -mfloat-abi=hard '
-                        '-mfpu=vfpv3-d16 -O3 -pipe -fstack-protector-strong '
-                        '-fno-plt -march=armv7-a -mfloat-abi=hard '
-                        '-mfpu=vfpv3-d16 -O3 -pipe -fstack-protector-strong '
-                        '-fno-plt -march=armv7-a -mfloat-abi=hard '
-                        '-mfpu=vfpv3-d16 -O3 -pipe -fstack-protector-strong '
-                        '-fno-plt -std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-O3 -Wall -march=armv7-a -mfloat-abi=hard -mfpu=neon '
+                        '-O3 -pipe -fstack-protector-strong -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-Werror=format-security         '
+                        '-fstack-clash-protection -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-Werror=format-security         '
+                        '-fstack-clash-protection -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt '
+                        '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                        '-Werror=format-security         '
+                        '-fstack-clash-protection -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 '
-                        '-fPIC',
+                        '-I./Include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -722,13 +757,13 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.2',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.3',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lcrypt -lpthread -ldl  -lutil -lm',
+ 'SHLIBS': '-lcrypt -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
- 'SHM_NEEDS_LIBRT': 1,
+ 'SHM_NEEDS_LIBRT': 0,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
@@ -764,9 +799,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.2 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.3 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.2 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.3 ./python '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -794,8 +829,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.10.2',
- 'abs_srcdir': '/build/python/src/Python-3.10.2',
+ 'abs_builddir': '/build/python/src/Python-3.10.3',
+ 'abs_srcdir': '/build/python/src/Python-3.10.3',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
